summaryrefslogtreecommitdiffstats
path: root/quanta/src/main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/src/main.cpp')
-rw-r--r--quanta/src/main.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/quanta/src/main.cpp b/quanta/src/main.cpp
index 3e11bacb..3b725f9d 100644
--- a/quanta/src/main.cpp
+++ b/quanta/src/main.cpp
@@ -177,10 +177,10 @@ int main(int argc, char *argv[])
I18N_NOOP("Splash screen and icon for 3.2"),
"luci@sh.ground.cz");
- KCmdLineArgs::init( argc, argv, &aboutData);
- KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
+ TDECmdLineArgs::init( argc, argv, &aboutData);
+ TDECmdLineArgs::addCmdLineOptions( options ); // Add our own options.
- // this defeats the purpose of KCmdLineArgs, but there is no other
+ // this defeats the purpose of TDECmdLineArgs, but there is no other
// way around, I'm afraid.
const char *uniq = "--unique";
bool isUnique = false;
@@ -199,7 +199,7 @@ int main(int argc, char *argv[])
KUniqueApplication::dcopClient()->registerAs("quanta-foo");
if (KUniqueApplication::dcopClient()->isApplicationRegistered("quanta"))
{
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
for (int i = 0; i < args->count(); i++)
{
TQString s = args->url(i).url();